@@ -5,17 +5,33 @@ library(nlme, quietly=TRUE, warn.conflicts=FALSE)
 data(Ovary, package = "nlme")
 
 Ovary$time_int <- 1:nrow(Ovary)
+
+lm_hom <- gls(follicles ~ sin(2*pi*Time) + cos(2*pi*Time), data = Ovary)
+lm_power <- gls(follicles ~ sin(2*pi*Time) + cos(2*pi*Time), data = Ovary,
+                weights = varPower())
 lm_AR1 <- gls(follicles ~ sin(2*pi*Time) + cos(2*pi*Time), data = Ovary,
               correlation = corAR1(form = ~ time_int | Mare))
 lm_AR1_power <- update(lm_AR1, weights = varPower())
 
+test_that("bread works", {
+  expect_true(check_bread(lm_hom, cluster = Ovary$Mare, y = Ovary$follicles))
+  expect_true(check_bread(lm_power, cluster = Ovary$Mare, y = Ovary$follicles))
+  expect_true(check_bread(lm_AR1, cluster = Ovary$Mare, y = Ovary$follicles))
+  expect_true(check_bread(lm_AR1_power, cluster = Ovary$Mare, y = Ovary$follicles))
+  
+  expect_equal(vcov(lm_hom), lm_hom$sigma^2 * bread(lm_hom) / v_scale(lm_hom))
+  expect_equal(vcov(lm_power), lm_power$sigma^2 * bread(lm_power) / v_scale(lm_power))
+  expect_equal(vcov(lm_AR1), lm_AR1$sigma^2 * bread(lm_AR1) / v_scale(lm_AR1))
+  expect_equal(vcov(lm_AR1_power), lm_AR1_power$sigma^2 * bread(lm_AR1_power) / v_scale(lm_AR1_power))
+})
+
 test_that("vcovCR options work for CR2", {
   CR2_AR1 <- vcovCR(lm_AR1, type = "CR2")
   expect_identical(vcovCR(lm_AR1, cluster = Ovary$Mare, type = "CR2"), CR2_AR1)
   expect_identical(vcovCR(lm_AR1, type = "CR2", inverse_var = TRUE), CR2_AR1)
   expect_false(identical(vcovCR(lm_AR1, type = "CR2", inverse_var = FALSE), CR2_AR1))
   
-  target <- targetVariance(lm_AR1, cluster = Ovary$Mare)
+  target <- targetVariance(lm_AR1)
   expect_equal(vcovCR(lm_AR1, type = "CR2", target = target, inverse_var = TRUE), CR2_AR1)
   attr(CR2_AR1, "inverse_var") <- FALSE
   expect_equal(vcovCR(lm_AR1, type = "CR2", target = target, inverse_var = FALSE), CR2_AR1)
@@ -62,8 +78,6 @@ test_that("CR2 and CR4 are target-unbiased", {
   expect_true(check_CR(lm_AR1_power, vcov = "CR4"))
 })
 
-
-
 test_that("getData works.", {
   re_order <- sample(nrow(Ovary))
   egg_scramble <- Ovary[re_order,]
@@ -79,19 +93,19 @@ CR_types <- paste0("CR",0:4)
 test_that("Order doesn't matter.", {
   re_order <- sample(nrow(Ovary))
   dat_scramble <- Ovary[re_order,]
-  lm_scramble <- update(lm_AR1, data = dat_scramble)
-  CR_fit <- lapply(CR_types, function(x) vcovCR(lm_AR1, type = x))
+  lm_scramble <- update(lm_AR1_power, data = dat_scramble)
+  CR_fit <- lapply(CR_types, function(x) vcovCR(lm_AR1_power, type = x))
   CR_scramble <- lapply(CR_types, function(x) vcovCR(lm_scramble, type = x))
-  expect_equivalent(CR_fit, CR_scramble)
+  expect_equal(lapply(CR_fit, as.matrix), lapply(CR_scramble, as.matrix), tol = 5 * 10^-7)
   
-  test_fit <- lapply(CR_types, function(x) coef_test(lm_AR1, vcov = x, test = "All"))
+  test_fit <- lapply(CR_types, function(x) coef_test(lm_AR1_power, vcov = x, test = "All"))
   test_scramble <- lapply(CR_types, function(x) coef_test(lm_scramble, vcov = x, test = "All"))
-  expect_equal(test_fit, test_scramble, tolerance = 10^-6)
+  expect_equal(test_fit, test_scramble, tolerance = 5 * 10^-6)
   
-  constraints <- combn(length(coef(lm_AR1)), 2, simplify = FALSE)
-  Wald_fit <- Wald_test(lm_AR1, constraints = constraints, vcov = "CR2", test = "All")
+  constraints <- combn(length(coef(lm_AR1_power)), 2, simplify = FALSE)
+  Wald_fit <- Wald_test(lm_AR1_power, constraints = constraints, vcov = "CR2", test = "All")
   Wald_scramble <- Wald_test(lm_scramble, constraints = constraints, vcov = "CR2", test = "All")
-  expect_equal(Wald_fit, Wald_scramble)
+  expect_equal(Wald_fit, Wald_scramble, tol = 5 * 10^-7)
 })
 
 
@@ -116,3 +130,4 @@ test_that("clubSandwich works with dropped observations", {
 
 test_that("CR2 is equivalent to Welch t-test for DiD design", {
 })
+
